CAPPr
=====

   | **C**\ompletion
   | **A**\fter
   | **P**\rompt
   | **Pr**\obability

| CAPPr performs text classification. No training or post-processing needed.
| Just have your LLM pick from a list of choices.
| Or compute the probability of a completion given a prompt.
| Squeeze `more <https://cappr.readthedocs.io/en/latest/statistical_performance.html>`_
  out of open source LLMs.


Get started
===========

.. toctree::
   :maxdepth: 2

   about


Get going
=========

.. toctree::
   :maxdepth: 2

   user_guide


Details
=======

.. toctree::
   :maxdepth: 2

   research


Package
=======

.. toctree::
   :maxdepth: 2

   cappr


Development
===========

.. toctree::
   :maxdepth: 2

   local


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
